@@ -1,9 +1,9 @@
 package ScriptX;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-09-03'; # DATE
+our $DATE = '2020-10-01'; # DATE
 our $DIST = 'ScriptX'; # DIST
-our $VERSION = '0.000001'; # VERSION
+our $VERSION = '0.000002'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -177,6 +177,7 @@ sub run {
     );
 }
 
+my $handler_seq = 0;
 sub add_handler {
     my ($event, $label, $prio, $handler) = @_;
 
@@ -185,7 +186,7 @@ sub add_handler {
 
     # keep sorted
     splice @{ $Handlers{$event} }, 0, scalar(@{ $Handlers{$event} }),
-        (sort { $a->[1] <=> $b->[1] } @{ $Handlers{$event} }, [$label, $prio, $handler]);
+        (sort { $a->[1] <=> $b->[1] || $a->[3] <=> $b->[3] } @{ $Handlers{$event} }, [$label, $prio, $handler, $handler_seq++]);
 }
 
 sub activate_plugin {
@@ -314,7 +315,7 @@ ScriptX - A plugin-based script framework
 
 =head1 VERSION
 
-This document describes version 0.000001 of ScriptX (from Perl distribution ScriptX), released on 2020-09-03.
+This document describes version 0.000002 of ScriptX (from Perl distribution ScriptX), released on 2020-10-01.
 
 =head1 SYNOPSIS
 
@@ -444,7 +445,7 @@ L</run_event>() to cancel the event.
 =head2 602
 
 This signifies repeating of event ("Repeat"), meaning the handler instructs
-L</run_event>() to cancel the event.
+L</run_event>() to repeat the event.
 
 =head1 FUNCTIONS
 
